==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Output/oss4/translations/oss4_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="36"/>
        <source>OSS4 Plugin</source>
        <translation>Módulo OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="56"/>
        <source>About OSS4 Output Plugin</source>
        <translation>Acerca del módulo de salida OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="57"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation>Módulo de salida OSS4 para Qmmp</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation>Configuración del módulo OSS4</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Output/oss4/translations/oss4_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="37"/>
        <source>OSS4 Plugin</source>
        <translation>Módulo OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="57"/>
        <source>About OSS4 Output Plugin</source>
        <translation>Acerca del módulo de salida OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation>Módulo de salida OSS4 para Qmmp</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation>Configuración del módulo OSS4</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
</context>
</TS>
